@@ -1,8 +1,8 @@
 #include "SWFFile.h"
 #include "SWFReader.h"
 #include "SWFWriter.h"
-#include <string.h>
-#include <stdlib.h>
+#include <cstring>
+#include <cstdlib>
 #include <zlib.h>
 
 namespace SWF {
@@ -15,6 +15,10 @@ File::File() {
 	header = NULL;
 }
 
+File::~File() {
+	delete header;
+}
+
 void File::dump() {
 	Context ctx;
 	if( !header ) {
@@ -83,7 +87,14 @@ int File::load( FILE *fp, Context *_ctx, unsigned int filesize ) {
 
 	header->parse( r, length, ctx );
 	
-	if( r->getError() != SWFR_OK ) goto fail;
+	if( r->getError() != SWFR_OK ) {
+		if( r->getError() == SWFR_EOF ) {
+			fprintf(stderr,"WARNING: reached EOF while reading SWF\n");
+		} else {
+			fprintf(stderr,"unknown error while reading SWF\n");
+			goto fail;
+		}
+	}	
 
 	if( r ) delete r;
 	if( !_ctx && ctx ) delete ctx;
@@ -91,7 +102,7 @@ int File::load( FILE *fp, Context *_ctx, unsigned int filesize ) {
 	return length+8;
 	
 fail:
-	if( data ) delete data;
+	if( data ) delete[] data;
 	if( !_ctx && ctx ) delete ctx;
 	return 0;
 }
@@ -146,14 +157,14 @@ int File::save( FILE *fp, Context *_ctx ) {
 	}
 
 	delete w;
-	delete data;
-	if( !_ctx && ctx ) delete ctx;
+	delete[] data;
+	if( !_ctx ) delete ctx;
 	return( length+8 );
 	
 fail:
-	if( w ) delete w;
-	if( data ) delete data;
-	if( !_ctx && ctx ) delete ctx;
+	delete w;
+	delete[] data;
+	if( !_ctx ) delete ctx;
 	return 0;
 }
 
@@ -161,7 +172,7 @@ xmlDocPtr File::getXML( Context *_ctx ) {
 	Context *ctx;
 	ctx = _ctx ? _ctx : new Context;
 
-	xmlDocPtr doc;
+	xmlDocPtr doc = 0;
 	xmlNodePtr root;
 	
 	if( !header ) {
@@ -182,12 +193,12 @@ xmlDocPtr File::getXML( Context *_ctx ) {
 	ctx->swfVersion = version;
 	header->writeXML( root, ctx );
 	
-	if( !_ctx && ctx ) delete ctx;
+	if( !_ctx ) delete ctx;
 	return doc;
 	
 fail:
-	if( doc ) xmlFree( doc );
-	if( !_ctx && ctx ) delete ctx;
+	if (doc) xmlFreeDoc(doc);
+	if( !_ctx ) delete ctx;
 	return NULL;
 }
 
@@ -202,11 +213,12 @@ int File::saveXML( FILE *fp, Context *ctx ) {
 	
 	if( size ) fwrite( data, size, 1, fp );
 
-	if( data ) delete[] data;
+	if( data ) xmlFree(data);
+	xmlFreeDoc(doc);
 	return size;
 	
 fail:
-	if( data ) delete[] data;
+	if( data ) xmlFree(data);
 	return 0;
 }
 
@@ -256,12 +268,12 @@ int File::setXML( xmlNodePtr root, Context *_ctx ) {
 	header->parseXML( headerNode, ctx );
 
 	length = (header->getSize(ctx,0)/8);
-		
-	if( !_ctx && ctx ) delete ctx;
+
+	if( !_ctx ) delete ctx;
 	return length+8;
 	
 fail:
-	if( !_ctx && ctx ) delete ctx;
+	if( !_ctx ) delete ctx;
 	return 0;
 }
 
@@ -278,7 +290,7 @@ int File::loadXML( const char *filename, Context *ctx ) {
 	
 	root = doc->xmlRootNode;
 	length = setXML( root, ctx );
-		
+
 	xmlFreeDoc( doc );
 	return length;
 	
