@@ -1,6 +1,6 @@
 #include "SWFItem.h"
-#include <string.h>
-#include <ctype.h>
+#include <cstring>
+#include <cctype>
 #include "base64.h"
 #include <sys/types.h>
 
@@ -125,14 +125,14 @@ Rest::Rest() {
 }
 
 Rest::~Rest() {
-	if( data ) delete data;
+	delete[] data;
 }
 
 bool Rest::parse( Reader *r, int end, Context *ctx ) {
 	file_offset = r->getPosition();
 
 	size = end - r->getPosition();
-	if( size ) {
+	if( size > 0 ) {
 		data = new unsigned char[size];
 		r->getData( data, size );
 	}
@@ -211,7 +211,7 @@ void Rest::parseXML( xmlNodePtr node, Context *ctx ) {
 			data = new unsigned char[ lout ];
 			memcpy( data, dst, lout );
 		}
-		delete dst;
+		delete[] dst;
 		xmlFree( xmld );
 	} 
 }
@@ -222,7 +222,7 @@ void Rest::getdata( unsigned char **d, int *s ) {
 }
 
 void Rest::setdata( unsigned char *d, int s ) {
-	if( data ) delete data;
+	delete[] data;
 	data = NULL;
 	size = s;
 	
