@@ -1,7 +1,7 @@
 #ifndef SWF_Writer_H
 #define SWF_Writer_H
 
-#include <stdio.h>
+#include <cstdio>
 #include <stdint.h>
 #include "SWFBasic.h"
 
@@ -22,11 +22,17 @@ class Writer {
 		void putWord(uint16_t);
 		void putInt(uint32_t);
 		void putInt64(uint64_t);
+		void putU30(uint32_t);
+		void putS24(int);
 		void putFloat(float);
 		void putDouble(double);
+		void putDouble2(double);
+		void putHalf(float);
 		void putFixed( double v, int bytesize, int decimals );
 		void putString( const char * );
 		void putPString( const char * );
+		void putPStringU30( const char * );
+		void putEncodedU32(unsigned int);
 	
 		// this one cares about the current bit position
 		void putNBitInt( int64_t v, int n, bool is_signed = false );
