@@ -2,8 +2,8 @@
 #include "SWFFile.h"
 #include "swft.h"
 #include "xslt.h"
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -16,41 +16,42 @@ using namespace SWF;
 bool quiet = false;
 bool verbose = false;
 bool dump = false;
+bool nonet = false;
 const char *internal_stylesheet = NULL;
 
 void usage() {
 	fprintf( stderr,
 		"\n"PACKAGE_NAME" "PACKAGE_VERSION"\n"
-		"     XML-based SWF (Shockwave Flash) processing tool\n"
+		"    XML-based SWF processing tool\n"
 		"\n"
 		"usage: swfmill [<options>] <command>\n"
 		"\n"
 		"<command> is one of:\n"
 		"    swf2xml <in> [<out>]\n"
-		"           convert from SWF to XML.\n"
-		"           <in> is a single SWF file, or 'stdin'\n"
-		"           <out> is a single XML file, or (by default) 'stdout'\n"
+		"        convert from SWF to XML.\n"
+		"        <in> is a single SWF file, or 'stdin'\n"
+		"        <out> is a single XML file, or (by default) 'stdout'\n"
 		"\n"
 		"    xml2swf <in> [<out>]\n"
-		"           convert from XML to SWF.\n"
-		"           <in> is a single XML file, or 'stdin'\n"
-		"           <out> is a single SWF file, or (by default) 'stdout'\n"
+		"        convert from XML to SWF.\n"
+		"        <in> is a single XML file, or 'stdin'\n"
+		"        <out> is a single SWF file, or (by default) 'stdout'\n"
 		"\n"
 		"    simple <in> [<out>]\n"
-		"           convert from a movie definition file to SWF.\n"
-		"           <in> is a single XML file, or 'stdin'\n"
-		"           <out> is a single SWF file, or (by default) 'stdout'\n"
-		"           (for details, see README)\n"
+		"        convert from a movie definition file to SWF.\n"
+		"        <in> is a single XML file, or 'stdin'\n"
+		"        <out> is a single SWF file, or (by default) 'stdout'\n"
+		"        (for details, see README)\n"
 		"\n"
 		"    xslt <xsl> <in> [<out>"
 		//" [<param>*]"
 		"]\n"
-		"           transform <in> to <out> as described by <xsl>.\n"
-		"           <xsl> is the XSLT stylesheet,\n"
-		"                 and can use the swft: extension.\n"
-		"           <in>  must be some XML (depends on <xsl>)\n"
-		"           <out> is either SWF (when it ends in .swf)\n"
-		"                 or XML, by default on 'stdout'\n"
+		"        transform <in> to <out> as described by <xsl>.\n"
+		"        <xsl> is the XSLT stylesheet,\n"
+		"            and can use the swft: extension.\n"
+		"        <in>  must be some XML (depends on <xsl>)\n"
+		"        <out> is either SWF (when it ends in .swf)\n"
+		"            or XML, by default on 'stdout'\n"
 //		"           <param>* is a whitespace-separated list of name=value\n"
 //		"                 assignments for xsl parameters\n"
 		"\n"
@@ -59,8 +60,9 @@ void usage() {
 		"    -v verbose output\n"
 		"    -V extra-verbose debugging output\n"
 		"    -d dump SWF data when loaded (for debugging)\n"
+		"    -n deactivate libxml network access\n"
 		"\n"
-		"E-mail bug reports to "PACKAGE_BUGREPORT"\n\n"
+		"Please report bugs at http://bugs.launchpad.net/swfmill/+filebug\n\n"
 	);
 }
 
@@ -428,6 +430,10 @@ int main( int argc, char *argv[] ) {
 					case 'd':
 						dump = true;
 						break;
+					case 'n':
+						nonet = true;
+						break;
+					case 'h':
 					case '?':
 						usage();
 						goto fail;
@@ -449,6 +455,8 @@ int main( int argc, char *argv[] ) {
 		goto fail;
 	}
 	
+	if( nonet ) xmlSetExternalEntityLoader( xmlNoNetExternalEntityLoader );
+	
 	if( !quiet ) fprintf( stderr, "%s %s\n", PACKAGE_NAME, PACKAGE_VERSION );
 
 	if( !strcmp( command, "swf2xml" ) ) {
