@@ -220,7 +220,10 @@ const char *xslt_simple =
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"text()\" mode=\"htmltext\">\n"
 "	<xsl:value-of select=\".\"/>\n"
 "</xsl:template>\n"
-"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"*|@*|text()\" priority=\"-1\">\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"@objectID|@sprite|@fontRef\">\n"
+"	<xsl:attribute name=\"{name()}\"><xsl:value-of select=\"swft:map-id(.)\"/></xsl:attribute>\n"
+"</xsl:template>\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"*|@*|text()\" priority=\"-2\">\n"
 "	<xsl:copy select=\".\">\n"
 "		<xsl:apply-templates select=\"*|@*|text()\"/>\n"
 "	</xsl:copy>\n"
@@ -291,6 +294,12 @@ const char *xslt_simple =
 "			<xsl:otherwise>0</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
+"	<xsl:variable name=\"as3\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@as3\">1</xsl:when>\n"
+"			<xsl:otherwise>0</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
 "\n"
 "	<swf version=\"{$version}\" compressed=\"{$compressed}\">\n"
 "		<Header framerate=\"{$framerate}\" frames=\"{$frames}\">\n"
@@ -298,8 +307,8 @@ const char *xslt_simple =
 "				<Rectangle left=\"{$left}\" right=\"{$right}\" top=\"{$top}\" bottom=\"{$bottom}\"/>\n"
 "			</size>\n"
 "			<tags>\n"
-"				<xsl:if test=\"$version = 8\">\n"
-"					<FileAttributes hasMetaData=\"{$hasMetaData}\" useNetwork=\"{$useNetwork}\"/>\n"
+"				<xsl:if test=\"$version &gt;= 8\">\n"
+"					<FileAttributes hasMetaData=\"{$hasMetaData}\" useNetwork=\"{$useNetwork}\" allowABC=\"{$as3}\"/>\n"
 "				</xsl:if>\n"
 "				<xsl:apply-templates/>\n"
 "				<End/>\n"
@@ -371,21 +380,56 @@ const char *xslt_simple =
 "			<xsl:otherwise>1</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
+"    <xsl:variable name=\"skewx\">\n"
+"            <xsl:choose>\n"
+"                    <xsl:when test=\"@skewx\"><xsl:value-of select=\"@skewx\"/></xsl:when>\n"
+"                    <xsl:otherwise>0</xsl:otherwise>\n"
+"            </xsl:choose>\n"
+"    </xsl:variable>\n"
+"    <xsl:variable name=\"skewy\">\n"
+"            <xsl:choose>\n"
+"                    <xsl:when test=\"@skewy\"><xsl:value-of select=\"@skewy\"/></xsl:when>\n"
+"                    <xsl:otherwise>0</xsl:otherwise>\n"
+"            </xsl:choose>\n"
+"    </xsl:variable>\n"
+"    <xsl:variable name=\"scalex\">\n"
+"            <xsl:choose>\n"
+"                    <xsl:when test=\"@scalex\"><xsl:value-of select=\"@scalex\"/></xsl:when>\n"
+"                    <xsl:when test=\"@scale\"><xsl:value-of select=\"@scale\"/></xsl:when>\n"
+"                    <xsl:otherwise>1</xsl:otherwise>\n"
+"            </xsl:choose>\n"
+"    </xsl:variable>\n"
+"    <xsl:variable name=\"scaley\">\n"
+"            <xsl:choose>\n"
+"                    <xsl:when test=\"@scaley\"><xsl:value-of select=\"@scaley\"/></xsl:when>\n"
+"                    <xsl:when test=\"@scale\"><xsl:value-of select=\"@scale\"/></xsl:when>\n"
+"                    <xsl:otherwise>1</xsl:otherwise>\n"
+"            </xsl:choose>\n"
+"    </xsl:variable>\n"
+"\n"
 "	<xsl:variable name=\"depth\"><xsl:value-of select=\"@depth\"/></xsl:variable>\n"
 "	\n"
-"	<!-- if we have a former place with the same depth, use morph=\"1\" replace=\"0\"\n"
-"		 using morph=\"0\" and replace=\"1\" only works for the same objectID\n"
-"		 that is already placed in layer (depth) -->\n"
+"	<!-- Setting replace=\"1\" doesn't work if we are replacing a sprite.\n"
+"		 Instead, we remove the previous sprite with RemoveObject2,\n"
+"		 and increment \"morph\". This strange requirement isn't\n"
+"		 documented anywhere, but this is what Flash does, and it\n"
+"		 works. See bug #409165 on Launchpad. -->\n"
 "	<xsl:variable name=\"replace\">\n"
 "		<xsl:choose>\n"
 "			<xsl:when test=\"preceding-sibling::place[@depth=$depth] or ../preceding-sibling::frame/place[@depth=$depth]\">1</xsl:when>\n"
 "			<xsl:otherwise>0</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
+"	<xsl:variable name=\"morph\">\n"
+"		<xsl:value-of select=\"count(preceding-sibling::place[@depth=$depth] |     ../preceding-sibling::frame/place[@depth=$depth])\"/>\n"
+"	</xsl:variable>\n"
 "	<xsl:if test=\"$replace = '1'\">\n"
 "		<RemoveObject2 depth=\"{@depth}\"/>\n"
 "	</xsl:if>\n"
-"	<PlaceObject2 replace=\"0\" morph=\"{$replace}\" depth=\"{$depth}\" objectID=\"{$id}\" name=\"{@name}\">\n"
+"	<PlaceObject2 replace=\"0\" morph=\"{$morph}\" depth=\"{$depth}\" objectID=\"{$id}\">\n"
+"		<xsl:if test=\"@name\">\n"
+"			<xsl:attribute name=\"name\"><xsl:value-of select=\"@name\"/></xsl:attribute>\n"
+"		</xsl:if>\n"
 "		<xsl:if test=\"*\">\n"
 "			<!-- 0x200: initialize -->\n"
 "			<xsl:attribute name=\"allflags1\">0x200</xsl:attribute>\n"
@@ -400,7 +444,7 @@ const char *xslt_simple =
 "			</events>\n"
 "		</xsl:if>\n"
 "		<transform>\n"
-"			<Transform transX=\"{$x}\" transY=\"{$y}\" scaleX=\"{$scale}\" scaleY=\"{$scale}\"/>\n"
+"			<Transform transX=\"{$x}\" transY=\"{$y}\" scaleX=\"{$scalex}\" scaleY=\"{$scaley}\" skewX=\"{$skewx}\" skewY=\"{$skewy}\"/>\n"
 "		</transform>\n"
 "	</PlaceObject2>\n"
 "</xsl:template>\n"
@@ -429,13 +473,41 @@ const char *xslt_simple =
 "			<xsl:otherwise>1</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
+"\n"
+"    <xsl:variable name=\"scalex\">\n"
+"            <xsl:choose>\n"
+"                    <xsl:when test=\"@scalex\"><xsl:value-of select=\"@scalex\"/></xsl:when>\n"
+"                    <xsl:when test=\"@scale\"><xsl:value-of select=\"@scale\"/></xsl:when>\n"
+"                    <xsl:otherwise>1</xsl:otherwise>\n"
+"            </xsl:choose>\n"
+"    </xsl:variable>\n"
+"    <xsl:variable name=\"scaley\">\n"
+"            <xsl:choose>\n"
+"                    <xsl:when test=\"@scaley\"><xsl:value-of select=\"@scaley\"/></xsl:when>\n"
+"                    <xsl:when test=\"@scale\"><xsl:value-of select=\"@scale\"/></xsl:when>\n"
+"                    <xsl:otherwise>1</xsl:otherwise>\n"
+"            </xsl:choose>\n"
+"    </xsl:variable>\n"
+"    <xsl:variable name=\"skewx\">\n"
+"            <xsl:choose>\n"
+"                    <xsl:when test=\"@skewx\"><xsl:value-of select=\"@skewx\"/></xsl:when>\n"
+"                    <xsl:otherwise>0</xsl:otherwise>\n"
+"            </xsl:choose>\n"
+"    </xsl:variable>\n"
+"    <xsl:variable name=\"skewy\">\n"
+"            <xsl:choose>\n"
+"                    <xsl:when test=\"@skewy\"><xsl:value-of select=\"@skewy\"/></xsl:when>\n"
+"                    <xsl:otherwise>0</xsl:otherwise>\n"
+"            </xsl:choose>\n"
+"    </xsl:variable>\n"
+" \n"
 "	<xsl:variable name=\"depth\">\n"
 "		<xsl:value-of select=\"preceding-sibling::place[@id=$myid]/@depth\"/>\n"
 "	</xsl:variable>\n"
 "	\n"
 "	<PlaceObject2 replace=\"1\" depth=\"{$depth}\" objectID=\"{$id}\">\n"
 "		<transform>\n"
-"			<Transform transX=\"{$x}\" transY=\"{$y}\" scaleX=\"{$scale}\" scaleY=\"{$scale}\"/>\n"
+"			<Transform transX=\"{$x}\" transY=\"{$y}\" scaleX=\"{$scalex}\" scaleY=\"{$scaley}\" skewX=\"{$skewx}\" skewY=\"{$skewy}\"/>\n"
 "		</transform>\n"
 "	</PlaceObject2>\n"
 "</xsl:template>\n"
@@ -633,7 +705,15 @@ const char *xslt_simple =
 "			</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
-"	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
+"	<xsl:variable name=\"frames\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"count(frame)\">\n"
+"				<xsl:value-of select=\"count(frame)\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>1</xsl:otherwise>\n"
+"        </xsl:choose>\n"
+"    </xsl:variable>\n"
+"	<DefineSprite objectID=\"{$id}\" frames=\"{$frames}\">\n"
 "		<tags>\n"
 "			<xsl:apply-templates/>\n"
 "			<End/>\n"
@@ -766,15 +846,28 @@ const char *xslt_simple =
 "		</xsl:when>\n"
 "		-->\n"
 "		<xsl:when test=\"$ext = 'svg'\">\n"
+"			<swft:push-map/>\n"
 "			<xsl:apply-templates select=\"document($file)\" mode=\"svg\">\n"
 "				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
+"				<xsl:with-param name=\"export\">\n"
+"					<xsl:choose>\n"
+"						<xsl:when test=\"@export\"><xsl:value-of select=\"@export\"/></xsl:when>\n"
+"						<xsl:otherwise>all</xsl:otherwise>\n"
+"					</xsl:choose>\n"
+"				</xsl:with-param>\n"
 "			</xsl:apply-templates>\n"
+"			<swft:pop-map/>\n"
 "		</xsl:when>\n"
 "		<xsl:when test=\"$ext = 'mp3'\">\n"
 "			<xsl:apply-templates select=\"swft:import-mp3($file)\" mode=\"makeswf\">\n"
 "				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
 "			</xsl:apply-templates>\n"
 "		</xsl:when>\n"
+"		<xsl:when test=\"$ext = 'wav'\">\n"
+"			<xsl:apply-templates select=\"swft:import-wav($file)\" mode=\"makeswf\">\n"
+"				<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
+"			</xsl:apply-templates>\n"
+"		</xsl:when>\n"
 "		<xsl:otherwise>\n"
 "			<xsl:message>WARNING: Cannot import <xsl:value-of select=\"$file\"/> (unknown extension), skipping.</xsl:message>\n"
 "		</xsl:otherwise>\n"
@@ -862,7 +955,32 @@ const char *xslt_simple =
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
 "\n"
-"	<xsl:apply-templates select=\"swft:import-ttf($file,@glyphs,@name,$offset)\" mode=\"makeswf\">\n"
+"	<xsl:apply-templates select=\"swft:import-ttf($file,$movie-version,@glyphs,@name,$offset)\" mode=\"makeswf\">\n"
+"		<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
+"	</xsl:apply-templates>\n"
+"\n"
+"	<xsl:if test=\"ancestor::library\">\n"
+"		<xsl:apply-templates select=\"*|@*\" mode=\"export\">\n"
+"			<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
+"		</xsl:apply-templates>\n"
+"	</xsl:if>\n"
+"</xsl:template>\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"binary[@import]\">\n"
+"	<xsl:variable name=\"id\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@id\">\n"
+"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>\n"
+"				<xsl:value-of select=\"swft:next-id()\"/>\n"
+"			</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"file\">\n"
+"		<xsl:value-of select=\"@import\"/>\n"
+"	</xsl:variable>\n"
+"	\n"
+"	<xsl:apply-templates select=\"swft:import-binary($file)\" mode=\"makeswf\">\n"
 "		<xsl:with-param name=\"id\"><xsl:value-of select=\"$id\"/></xsl:with-param>\n"
 "	</xsl:apply-templates>\n"
 "\n"
@@ -1073,6 +1191,14 @@ const char *xslt_simple =
 "	</DefineSprite>\n"
 "	<swft:pop-map/>\n"
 "</xsl:template>\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"binary\" mode=\"makeswf\">\n"
+"	<xsl:param name=\"id\"/>\n"
+"	<DefineBinaryData objectID=\"{$id}\">\n"
+"		<data>\n"
+"			<xsl:copy-of select=\"data\"/>\n"
+"		</data>\n"
+"	</DefineBinaryData>\n"
+"</xsl:template>\n"
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"@objectID|@fontRef|@sprite\" mode=\"idmap\">\n"
 "	<xsl:attribute name=\"{name()}\"><xsl:value-of select=\"swft:map-id(.)\"/></xsl:attribute>\n"
 "</xsl:template>\n"
@@ -1088,7 +1214,7 @@ const char *xslt_simple =
 "		<xsl:apply-templates mode=\"idmap\"/>\n"
 "	</xsl:copy>\n"
 "</xsl:template>\n"
-"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"SetBackgroundColor\" mode=\"sprite-global\"/>\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"SetBackgroundColor|FileAttributes\" mode=\"sprite-global\"/>\n"
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"DoAction|End|FrameLabel|PlaceObject|PlaceObject2|RemoveObject|RemoveObject2|ShowFrame|SoundStreamBlock|SoundStreamHead|StartSound\" mode=\"sprite-global\"/>\n"
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"*|@*|text()\" mode=\"sprite-global\" priority=\"-1\">\n"
 "	<xsl:apply-templates select=\".\" mode=\"idmap\"/>\n"
@@ -1148,9 +1274,18 @@ const char *xslt_simple =
 "</xsl:template>\n"
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"ttf\" mode=\"makeswf\">\n"
 "	<xsl:param name=\"id\"/>\n"
-"	<DefineFont2 objectID=\"{$id}\">\n"
-"		<xsl:copy-of select=\"DefineFont2/*|DefineFont2/@*[name() != 'objectID']\"/>\n"
-"	</DefineFont2>\n"
+"	<xsl:choose>\n"
+"		<xsl:when test=\"$movie-version &gt;= 8\">\n"
+"			<DefineFont3 objectID=\"{$id}\">\n"
+"				<xsl:copy-of select=\"DefineFont3/*|DefineFont3/@*[name() != 'objectID']\"/>\n"
+"			</DefineFont3>\n"
+"		</xsl:when>\n"
+"		<xsl:otherwise>\n"
+"			<DefineFont2 objectID=\"{$id}\">\n"
+"				<xsl:copy-of select=\"DefineFont2/*|DefineFont2/@*[name() != 'objectID']\"/>\n"
+"			</DefineFont2>\n"
+"		</xsl:otherwise>\n"
+"	</xsl:choose>\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"mp3\" mode=\"makeswf\">\n"
 "	<xsl:param name=\"id\"/>\n"
@@ -1160,6 +1295,17 @@ const char *xslt_simple =
 "		</data>\n"
 "	</DefineSound>\n"
 "</xsl:template>\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"wav\" mode=\"makeswf\">\n"
+"	<xsl:param name=\"id\"/>\n"
+"	<DefineSound objectID=\"{$id}\" format=\"{@format}\" rate=\"{@rate}\" is16bit=\"{@is16bit}\" stereo=\"{@stereo}\" samples=\"{@samples}\">\n"
+"		<data>\n"
+"			<xsl:copy-of select=\"data\"/>\n"
+"		</data>\n"
+"	</DefineSound>\n"
+"</xsl:template>\n"
+"<xsl:template xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:math=\"http://exslt.org/math\" match=\"include[@file]\">\n"
+"	<xsl:apply-templates select=\"document(@file)/movie/*\"/>	\n"
+"</xsl:template>\n"
 "	\n"
 "<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" name=\"transform\">\n"
 "	<transform>\n"
@@ -1182,8 +1328,11 @@ const char *xslt_simple =
 "			<xsl:when test=\"name()='use'\">\n"
 "				<xsl:value-of select=\"swft:map-id(substring(@xlink:href,2))\"/>\n"
 "			</xsl:when>\n"
-"			<xsl:otherwise>\n"
+"			<xsl:when test=\"@id\">\n"
 "				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>\n"
+"				<xsl:value-of select=\"swft:map-id(generate-id(.))\"/>\n"
 "			</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
@@ -1201,8 +1350,11 @@ const char *xslt_simple =
 "					</xsl:otherwise>\n"
 "				</xsl:choose>\n"
 "			</xsl:when>\n"
-"			<xsl:otherwise>\n"
+"			<xsl:when test=\"@id\">\n"
 "				<xsl:value-of select=\"@id\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>\n"
+"				<xsl:value-of select=\"generate-id(.)\"/>\n"
 "			</xsl:otherwise>\n"
 "		</xsl:choose>\n"
 "	</xsl:variable>\n"
@@ -1224,7 +1376,16 @@ const char *xslt_simple =
 "</xsl:template>\n"
 "<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" name=\"wrapElement\">\n"
 "	<xsl:param name=\"innerid\"/>\n"
-"	<xsl:variable name=\"id\" select=\"swft:map-id(@id)\"/>\n"
+"	<xsl:variable name=\"id\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@id\">\n"
+"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>\n"
+"				<xsl:value-of select=\"swft:map-id(generate-id(.))\"/>\n"
+"			</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
 "	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
 "		<tags>\n"
 "			<PlaceObject2 replace=\"0\" depth=\"{swft:next-depth()}\" objectID=\"{$innerid}\">\n"
@@ -1236,30 +1397,37 @@ const char *xslt_simple =
 "	</DefineSprite>\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" name=\"exportElement\">\n"
-"	<xsl:variable name=\"id\" select=\"swft:map-id(@id)\"/>\n"
-"	<xsl:variable name=\"name\" select=\"@id\"/>\n"
 "	<!-- export the element. -->\n"
 "	<xsl:if test=\"@id\">\n"
+"		<xsl:variable name=\"id\" select=\"swft:map-id(@id)\"/>\n"
+"		<xsl:variable name=\"name\" select=\"@id\"/>\n"
+"\n"
 "		<Export>\n"
 "			<symbols>\n"
 "				<Symbol objectID=\"{$id}\" name=\"{$name}\"/>\n"
 "			</symbols>\n"
 "		</Export>\n"
 "	</xsl:if>\n"
+"\n"
 "	<!-- define a class, if applicable. -->\n"
-"	<xsl:variable name=\"class\" select=\"@class\"/>\n"
-"	<xsl:if test=\"string-length($class) &gt; 0\">\n"
+"	<xsl:variable name=\"swfClass\" select=\"@swfClass\"/>\n"
+"	<xsl:if test=\"string-length($swfClass) &gt; 0\">\n"
 "		<xsl:call-template name=\"register-class\">\n"
-"			<xsl:with-param name=\"class\" select=\"$class\"/>\n"
-"			<xsl:with-param name=\"linkage-id\" select=\"$name\"/>\n"
+"			<xsl:with-param name=\"class\" select=\"$swfClass\"/>\n"
+"			<xsl:with-param name=\"linkage-id\" select=\"@id\"/>\n"
 "		</xsl:call-template>\n"
 "	</xsl:if>\n"
-"\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:svg\" mode=\"svg\">\n"
 "	<xsl:param name=\"id\"/>\n"
+"	<xsl:param name=\"export\"/>\n"
+"	<!-- initiate the gradient pass. -->\n"
+"	<xsl:apply-templates mode=\"gradient1\"/>\n"
+"	<xsl:apply-templates mode=\"gradient2\"/>\n"
 "	<!-- initiate the definition pass. -->\n"
-"	<xsl:apply-templates mode=\"queue\"/>\n"
+"	<xsl:apply-templates mode=\"queue\">\n"
+"		<xsl:with-param name=\"export\" select=\"$export\"/>\n"
+"	</xsl:apply-templates>\n"
 "	<!-- define svg root as sprite. -->\n"
 "	<DefineSprite objectID=\"{$id}\" frames=\"1\">\n"
 "		<tags>\n"
@@ -1270,27 +1438,67 @@ const char *xslt_simple =
 "		</tags>\n"
 "	</DefineSprite>\n"
 "</xsl:template>\n"
-"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:g|svg:path|svg:rect|svg:use|svg:text|svg:flowRoot\" mode=\"queue\">\n"
-"	<xsl:variable name=\"id\"><xsl:value-of select=\"swft:map-id(@id)\"/></xsl:variable>\n"
-"	<xsl:variable name=\"name\" select=\"@id\"/>\n"
+"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:linearGradient[not(@xlink:href)]|svg:radialGradient[not(@xlink:href)]\" mode=\"gradient1\">\n"
+"	<swft:push-gradient/>\n"
+"</xsl:template>\n"
+"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:linearGradient[@xlink:href]|svg:radialGradient[@xlink:href]\" mode=\"gradient2\">\n"
+"	<swft:push-gradient/>\n"
+"</xsl:template>\n"
+"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:g|svg:path|svg:rect|svg:circle|svg:ellipse|svg:line|svg:polyline|svg:polygon|svg:use|svg:text|svg:flowRoot\" mode=\"queue\">\n"
+"	<xsl:param name=\"export\"/>\n"
+"\n"
+"	<xsl:if test=\"name()='g'\">\n"
+"		<swft:push-style/>\n"
+"	</xsl:if>\n"
+"\n"
+"	<xsl:variable name=\"id\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@id\">\n"
+"				<xsl:value-of select=\"swft:map-id(@id)\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>\n"
+"				<xsl:value-of select=\"swft:map-id(generate-id(.))\"/>\n"
+"			</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
+"	<xsl:variable name=\"name\">\n"
+"		<xsl:choose>\n"
+"			<xsl:when test=\"@id\">\n"
+"				<xsl:value-of select=\"@id\"/>\n"
+"			</xsl:when>\n"
+"			<xsl:otherwise>\n"
+"				<xsl:value-of select=\"generate-id(.)\"/>\n"
+"			</xsl:otherwise>\n"
+"		</xsl:choose>\n"
+"	</xsl:variable>\n"
 "\n"
 "	<!-- first define the subparts, so that we get the innermost ones queued \n"
 "first. -->\n"
-"	<xsl:apply-templates mode=\"queue\"/>\n"
+"	<xsl:apply-templates mode=\"queue\">\n"
+"		<xsl:with-param name=\"export\" select=\"$export\"/>\n"
+"	</xsl:apply-templates>\n"
+"\n"
 "	<!-- now define this element, which is based on the subparts. -->\n"
 "	<xsl:apply-templates select=\".\" mode=\"definition\">\n"
 "		<xsl:with-param name=\"id\" select=\"$id\"/>\n"
 "		<xsl:with-param name=\"name\" select=\"$name\"/>\n"
+"		<xsl:with-param name=\"export\" select=\"$export\"/>\n"
 "	</xsl:apply-templates>\n"
 "\n"
+"	<xsl:if test=\"name()='g'\">\n"
+"		<swft:pop-style/>\n"
+"	</xsl:if>\n"
 "</xsl:template>\n"
-"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:g|svg:path|svg:rect|svg:use|svg:text|svg:flowRoot\" mode=\"placement\">\n"
-"	<!-- no definition. just place this element. -->\n"
-"	<xsl:call-template name=\"placeObject\"/>\n"
+"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:g|svg:path|svg:rect|svg:circle|svg:ellipse|svg:line|svg:polyline|svg:polygon|svg:use|svg:text|svg:flowRoot\" mode=\"placement\">\n"
+"	<xsl:if test=\"not(ancestor::svg:defs) or parent::svg:g\">\n"
+"		<!-- no definition. just place this element. -->\n"
+"		<xsl:call-template name=\"placeObject\"/>\n"
+"	</xsl:if>\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:g\" mode=\"definition\" priority=\"-1\">\n"
 "	<xsl:param name=\"id\"/>\n"
 "	<xsl:param name=\"name\"/>\n"
+"	<xsl:param name=\"export\"/>\n"
 "\n"
 "	<!-- test if a wrapper is needed for a group transform -->\n"
 "	<xsl:choose>\n"
@@ -1319,61 +1527,33 @@ const char *xslt_simple =
 "			</xsl:call-template>\n"
 "		</xsl:otherwise>\n"
 "	</xsl:choose>\n"
-"	<!-- export -->\n"
-"	<xsl:call-template name=\"exportElement\"/>\n"
 "\n"
+"\n"
+"	<!-- export -->\n"
+"	<xsl:if test=\"$export = 'all' or $export = 'groups'\">\n"
+"		<xsl:call-template name=\"exportElement\"/>\n"
+"	</xsl:if>\n"
 "</xsl:template>\n"
-"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:path\" mode=\"definition\">\n"
+"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:rect|svg:circle|svg:ellipse|svg:line|svg:polyline|svg:polygon|svg:path\" mode=\"definition\">\n"
 "	<xsl:param name=\"id\"/>\n"
+"	<xsl:param name=\"export\"/>\n"
 "	<xsl:variable name=\"shapeid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable>\n"
 "\n"
 "	<!-- define the path -->\n"
-"	<xsl:copy-of select=\"swft:path( @d, $shapeid, @style )\"/>\n"
+"	<xsl:copy-of select=\"swft:path(., $shapeid, $movie-version)\"/>\n"
 "	<!-- wrap in sprite -->\n"
 "	<xsl:call-template name=\"wrapElement\">\n"
 "		<xsl:with-param name=\"innerid\" select=\"$shapeid\"/>\n"
 "	</xsl:call-template>\n"
 "	<!-- export -->\n"
-"	<xsl:call-template name=\"exportElement\"/>\n"
-"</xsl:template>\n"
-"<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:rect\" mode=\"definition\">\n"
-"	<xsl:param name=\"id\"/>\n"
-"	<xsl:param name=\"name\"/>\n"
-"	<xsl:variable name=\"shapeid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable>\n"
-"\n"
-"	<!-- define the element -->\n"
-"	<DefineShape3 objectID=\"{$shapeid}\">\n"
-"		<bounds>\n"
-"			<Rectangle left=\"{@x}\" right=\"{(@x+@width)*20}\" top=\"{@y}\" bottom=\"{(@y+@height)*20}\"/>\n"
-"		</bounds>\n"
-"		<styles>\n"
-"			<StyleList>\n"
-"				<xsl:copy-of select=\"swft:css(@style)/tmp/*\"/>\n"
-"			</StyleList>\n"
-"		</styles>\n"
-"		<shapes>\n"
-"			<Shape>\n"
-"				<edges>\n"
-"					<ShapeSetup x=\"{(@x+@width)*20}\" y=\"{(@y+@height)*20}\" fillStyle0=\"1\" lineStyle=\"1\"/>\n"
-"					<LineTo x=\"-{(@width)*20}\" y=\"0\"/>\n"
-"					<LineTo x=\"0\" y=\"-{(@height)*20}\"/>\n"
-"					<LineTo x=\"{(@width)*20}\" y=\"0\"/>\n"
-"					<LineTo x=\"0\" y=\"{(@height)*20}\"/>\n"
-"					<ShapeSetup/>\n"
-"				</edges>\n"
-"			</Shape>\n"
-"		</shapes>\n"
-"	</DefineShape3>\n"
-"	<!-- wrap in sprite -->\n"
-"	<xsl:call-template name=\"wrapElement\">\n"
-"		<xsl:with-param name=\"innerid\" select=\"$shapeid\"/>\n"
-"	</xsl:call-template>\n"
-"	<!-- export -->\n"
-"	<xsl:call-template name=\"exportElement\"/>\n"
+"	<xsl:if test=\"$export = 'all'\">\n"
+"		<xsl:call-template name=\"exportElement\"/>\n"
+"	</xsl:if>\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:flowRoot\" mode=\"definition\">\n"
 "	<xsl:param name=\"id\"/>\n"
 "	<xsl:param name=\"name\"/>\n"
+"	<xsl:param name=\"export\"/>\n"
 "	<xsl:variable name=\"shapeid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable>\n"
 "\n"
 "	<!-- define the element -->\n"
@@ -1393,11 +1573,14 @@ const char *xslt_simple =
 "		<xsl:with-param name=\"innerid\" select=\"$shapeid\"/>\n"
 "	</xsl:call-template>\n"
 "	<!-- export -->\n"
-"	<xsl:call-template name=\"exportElement\"/>\n"
+"	<xsl:if test=\"$export = 'all'\">\n"
+"		<xsl:call-template name=\"exportElement\"/>\n"
+"	</xsl:if>\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:text\" mode=\"definition\">\n"
 "	<xsl:param name=\"id\"/>\n"
 "	<xsl:param name=\"name\"/>\n"
+"	<xsl:param name=\"export\"/>\n"
 "	<xsl:variable name=\"shapeid\"><xsl:value-of select=\"swft:next-id()\"/></xsl:variable>\n"
 "\n"
 "	<!-- define the element -->\n"
@@ -1406,7 +1589,7 @@ const char *xslt_simple =
 "		<xsl:apply-templates mode=\"svg-text\"/>\n"
 "	</xsl:attribute>\n"
 "	<size>\n"
-"		<Rectangle left=\"{@x * 20}\" right=\"{@x * 30}\" top=\"{@y * 20}\" bottom=\"{@y  * 30}\"/>\n"
+"		<Rectangle left=\"{@x * 20}\" right=\"{(@x + 200) * 20}\" top=\"{@y * 20 - 240}\" bottom=\"{@y  * 20}\"/>\n"
 "	</size>\n"
 "	<color>\n"
 "		<Color red=\"0\" green=\"0\" blue=\"0\" alpha=\"255\"/>\n"
@@ -1417,7 +1600,9 @@ const char *xslt_simple =
 "		<xsl:with-param name=\"innerid\" select=\"$shapeid\"/>\n"
 "	</xsl:call-template>\n"
 "	<!-- export -->\n"
-"	<xsl:call-template name=\"exportElement\"/>\n"
+"	<xsl:if test=\"$export = 'all'\">\n"
+"		<xsl:call-template name=\"exportElement\"/>\n"
+"	</xsl:if>\n"
 "</xsl:template>\n"
 "<xsl:template xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\" xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\" xmlns:svg=\"http://www.w3.org/2000/svg\" xmlns:swft=\"http://subsignal.org/swfml/swft\" xmlns:str=\"http://exslt.org/strings\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" match=\"svg:flowRegion\" mode=\"svg-text\">\n"
 "	<xsl:apply-templates mode=\"svg-text\"/>\n"
